@@ -288,7 +288,7 @@ class BpmnValidator():
         self.options = options
 
     def validate(self, input_):
-        cache()
+        cache(self.options)
         if self.options.verbose:
             print('validating...')
 
@@ -303,11 +303,11 @@ class BpmnValidator():
                         dom = ET.parse(root+'/'+file_)
                         for proc in dom.findall('//bpmn:process[@isExecutable="true"]', NS):
                             proc_id = proc.attrib['id']
-                        if proc_ids.count(proc_id):
-                            print('ERROR: More than one file contains process with id %s' % (proc_id))
-                            raise KpException(Error.IMPL_DUPE_ID)
-                else:
-                    proc_ids.append(proc_id)
+                            if proc_ids.count(proc_id):
+                                print('ERROR: More than one file contains process with id %s' % (proc_id))
+                                raise KpException(Error.IMPL_DUPE_ID)
+                            else:
+                                proc_ids.append(proc_id)
 
         if self.options.verbose:
             print('...done')
@@ -823,7 +823,7 @@ class Curl():
             if self.options.verbose:
                 print('ERROR: {}: {}'.format(e.code, e.reason))
 
-def cache():
+def cache(args):
     if args.verbose:
         print('caching external resources...')
 
@@ -964,7 +964,7 @@ def main():
 
     try:
         if args.cmd == 'cache':
-            cache()
+            cache(args)
         elif args.cmd == 'validate':
             validator.validate(args.input)
         elif args.cmd == 'describe':
@@ -995,3 +995,6 @@ def main():
     except KpException as e:
         sys.exit(e.err.value)
 
+# Do it!
+kpctl.main()
+
